PyXMake Developer Guide: PyXMake.VTL.api Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Functions | Variables
PyXMake.VTL.api Namespace Reference

## Functions
def | api_self_guide ()
def | api_user_guide ()
def | api_dev_guide ()
def | api_abaqus
def | api_cxx
def | api_doxygen
def | api_ifort
def | api_java
def | api_py2x
def | api_ssh_f2py
def | api_ssh_ifort
def | api_ssh_make
def | invalid_request
def | main (Hostname=str(platform.node()), PortID=8020)

## Variables
| app
| tags

## Detailed Description

    API setup example for PyXMake.

    @note: Run HTML APIs of PyXMake (in a Docker container or locally).
    Created on 28.02.2020

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - PyXMake

    @change:
          -

    @author: garb_ma                                      [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ api_dev_guide()

def PyXMake.VTL.api.api_dev_guide | ( |  | ) |

    Method pointing to the developer documentation of the underlying package.

Definition at line 81 of file api.py.

## ◆ api_self_guide()

def PyXMake.VTL.api.api_self_guide | ( |  | ) |

    Method pointing to the main documentation of the API.

Definition at line 67 of file api.py.

## ◆ api_user_guide()

def PyXMake.VTL.api.api_user_guide | ( |  | ) |

    Method pointing to the user documentation of the underlying package.

Definition at line 74 of file api.py.

## ◆ main()

def PyXMake.VTL.api.main | ( |  | Hostname = `str(platform.node())`,
|  |  | PortID = `8020`
| ) |  |

    Importable main function of current API.

Definition at line 216 of file api.py.

## Variable Documentation

## ◆ app

PyXMake.VTL.api.app

Initial value:
1 = FastAPI(title="PyXMake API",
2 version ="1.0",
3 description ="PyXMake is a python based make tool for daily software builds. This comprises daily library compilation for Python using f2py \
4 (currently MCODAC, BoxBeam & Beos), daily updated html documentations using Doxygen (currently MCODAC, BoxBeam, PyXMake & PyCODAC) \
5 and builds of shared & static libraries using Intel Fortran (currently MCODAC, BoxBeam). ",
6 docs_url = __pyx_api_delimn.join(["",str(PyXMake.__name__),"api","documentation"]))

Definition at line 53 of file api.py.